@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.5 (default, Sep  4 2020, 07:30:14)  [GCC 7.3.0]
+# Python 3.8.8 (default, Feb 24 2021, 21:46:12)  [GCC 7.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -988,89 +988,89 @@ class oneperEnumType01_1(str, Enum):
     TOKEN='token'
 
 
-class oneperType03_1(GeneratedsSuper):
+class oneperType01_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('helpername', 'xs:string', 0, 0, {'name': 'helpername', 'type': 'xs:string'}, None),
-        MemberSpec_('inner01', 'oneperType02_2', 0, 0, {'name': 'inner01', 'type': 'oneperType02_2'}, None),
+        MemberSpec_('username', 'xs:string', 0, 0, {'name': 'username', 'type': 'xs:string'}, None),
+        MemberSpec_('inner01', 'oneperType01_2', 0, 0, {'name': 'inner01', 'type': 'oneperType01_2'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, helpername=None, inner01=None, gds_collector_=None, **kwargs_):
+    def __init__(self, username=None, inner01=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.helpername = helpername
-        self.helpername_nsprefix_ = None
+        self.username = username
+        self.username_nsprefix_ = None
         self.inner01 = inner01
         self.inner01_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType03_1)
+                CurrentSubclassModule_, oneperType01_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType03_1.subclass:
-            return oneperType03_1.subclass(*args_, **kwargs_)
+        if oneperType01_1.subclass:
+            return oneperType01_1.subclass(*args_, **kwargs_)
         else:
-            return oneperType03_1(*args_, **kwargs_)
+            return oneperType01_1(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_helpername(self):
-        return self.helpername
-    def set_helpername(self, helpername):
-        self.helpername = helpername
+    def get_username(self):
+        return self.username
+    def set_username(self, username):
+        self.username = username
     def get_inner01(self):
         return self.inner01
     def set_inner01(self, inner01):
         self.inner01 = inner01
     def hasContent_(self):
         if (
-            self.helpername is not None or
+            self.username is not None or
             self.inner01 is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_1', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType03_1')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_1')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType03_1':
+        if self.original_tagname_ is not None and name_ == 'oneperType01_1':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType03_1')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_1')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType03_1', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_1', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType03_1'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_1'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_1', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_1', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.helpername is not None:
-            namespaceprefix_ = self.helpername_nsprefix_ + ':' if (UseCapturedNS_ and self.helpername_nsprefix_) else ''
+        if self.username is not None:
+            namespaceprefix_ = self.username_nsprefix_ + ':' if (UseCapturedNS_ and self.username_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%shelpername>%s</%shelpername>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.helpername), input_name='helpername')), namespaceprefix_ , eol_))
+            outfile.write('<%susername>%s</%susername>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.username), input_name='username')), namespaceprefix_ , eol_))
         if self.inner01 is not None:
             namespaceprefix_ = self.inner01_nsprefix_ + ':' if (UseCapturedNS_ and self.inner01_nsprefix_) else ''
             self.inner01.export(outfile, level, namespaceprefix_, namespacedef_='', name_='inner01', pretty_print=pretty_print)
@@ -1088,95 +1088,95 @@ class oneperType03_1(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'helpername':
+        if nodeName_ == 'username':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'helpername')
-            value_ = self.gds_validate_string(value_, node, 'helpername')
-            self.helpername = value_
-            self.helpername_nsprefix_ = child_.prefix
+            value_ = self.gds_parse_string(value_, node, 'username')
+            value_ = self.gds_validate_string(value_, node, 'username')
+            self.username = value_
+            self.username_nsprefix_ = child_.prefix
         elif nodeName_ == 'inner01':
-            obj_ = oneperType02_2.factory(parent_object_=self)
+            obj_ = oneperType01_2.factory(parent_object_=self)
             obj_.build(child_, gds_collector_=gds_collector_)
             self.inner01 = obj_
             obj_.original_tagname_ = 'inner01'
-# end class oneperType03_1
+# end class oneperType01_1
 
 
-class oneperType03_2(GeneratedsSuper):
+class oneperType01_2(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = [
-        MemberSpec_('helperdescription', 'xs:string', 0, 0, {'name': 'helperdescription', 'type': 'xs:string'}, None),
+        MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
     ]
     subclass = None
     superclass = None
-    def __init__(self, helperdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
         self.gds_elementtree_node_ = None
         self.original_tagname_ = None
         self.parent_object_ = kwargs_.get('parent_object_')
         self.ns_prefix_ = None
-        self.helperdescription = helperdescription
-        self.helperdescription_nsprefix_ = None
+        self.userdescription = userdescription
+        self.userdescription_nsprefix_ = None
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, oneperType03_2)
+                CurrentSubclassModule_, oneperType01_2)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if oneperType03_2.subclass:
-            return oneperType03_2.subclass(*args_, **kwargs_)
+        if oneperType01_2.subclass:
+            return oneperType01_2.subclass(*args_, **kwargs_)
         else:
-            return oneperType03_2(*args_, **kwargs_)
+            return oneperType01_2(*args_, **kwargs_)
     factory = staticmethod(factory)
     def get_ns_prefix_(self):
         return self.ns_prefix_
     def set_ns_prefix_(self, ns_prefix):
         self.ns_prefix_ = ns_prefix
-    def get_helperdescription(self):
-        return self.helperdescription
-    def set_helperdescription(self, helperdescription):
-        self.helperdescription = helperdescription
+    def get_userdescription(self):
+        return self.userdescription
+    def set_userdescription(self, userdescription):
+        self.userdescription = userdescription
     def hasContent_(self):
         if (
-            self.helperdescription is not None
+            self.userdescription is not None
         ):
             return True
         else:
             return False
-    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_2', pretty_print=True):
-        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType03_2')
+    def export(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', pretty_print=True):
+        imported_ns_def_ = GenerateDSNamespaceDefs_.get('oneperType01_2')
         if imported_ns_def_ is not None:
             namespacedef_ = imported_ns_def_
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.original_tagname_ is not None and name_ == 'oneperType03_2':
+        if self.original_tagname_ is not None and name_ == 'oneperType01_2':
             name_ = self.original_tagname_
         if UseCapturedNS_ and self.ns_prefix_:
             namespaceprefix_ = self.ns_prefix_ + ':'
         showIndent(outfile, level, pretty_print)
         outfile.write('<%s%s%s' % (namespaceprefix_, name_, namespacedef_ and ' ' + namespacedef_ or '', ))
         already_processed = set()
-        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType03_2')
+        self.exportAttributes(outfile, level, already_processed, namespaceprefix_, name_='oneperType01_2')
         if self.hasContent_():
             outfile.write('>%s' % (eol_, ))
-            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType03_2', pretty_print=pretty_print)
+            self.exportChildren(outfile, level + 1, namespaceprefix_, namespacedef_, name_='oneperType01_2', pretty_print=pretty_print)
             showIndent(outfile, level, pretty_print)
             outfile.write('</%s%s>%s' % (namespaceprefix_, name_, eol_))
         else:
             outfile.write('/>%s' % (eol_, ))
-    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType03_2'):
+    def exportAttributes(self, outfile, level, already_processed, namespaceprefix_='', name_='oneperType01_2'):
         pass
-    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType03_2', fromsubclass_=False, pretty_print=True):
+    def exportChildren(self, outfile, level, namespaceprefix_='', namespacedef_='', name_='oneperType01_2', fromsubclass_=False, pretty_print=True):
         if pretty_print:
             eol_ = '\n'
         else:
             eol_ = ''
-        if self.helperdescription is not None:
-            namespaceprefix_ = self.helperdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.helperdescription_nsprefix_) else ''
+        if self.userdescription is not None:
+            namespaceprefix_ = self.userdescription_nsprefix_ + ':' if (UseCapturedNS_ and self.userdescription_nsprefix_) else ''
             showIndent(outfile, level, pretty_print)
-            outfile.write('<%shelperdescription>%s</%shelperdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.helperdescription), input_name='helperdescription')), namespaceprefix_ , eol_))
+            outfile.write('<%suserdescription>%s</%suserdescription>%s' % (namespaceprefix_ , self.gds_encode(self.gds_format_string(quote_xml(self.userdescription), input_name='userdescription')), namespaceprefix_ , eol_))
     def build(self, node, gds_collector_=None):
         self.gds_collector_ = gds_collector_
         if SaveElementTreeNode:
@@ -1191,17 +1191,17 @@ class oneperType03_2(GeneratedsSuper):
     def buildAttributes(self, node, attrs, already_processed):
         pass
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
-        if nodeName_ == 'helperdescription':
+        if nodeName_ == 'userdescription':
             value_ = child_.text
-            value_ = self.gds_parse_string(value_, node, 'helperdescription')
-            value_ = self.gds_validate_string(value_, node, 'helperdescription')
-            self.helperdescription = value_
-            self.helperdescription_nsprefix_ = child_.prefix
-# end class oneperType03_2
+            value_ = self.gds_parse_string(value_, node, 'userdescription')
+            value_ = self.gds_validate_string(value_, node, 'userdescription')
+            self.userdescription = value_
+            self.userdescription_nsprefix_ = child_.prefix
+# end class oneperType01_2
 
 
 GDSClassesMapping = {
-    'root03': oneperType03_1,
+    'root01': oneperType01_1,
 }
 
 
@@ -1248,8 +1248,8 @@ def parse(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType03_1'
-        rootClass = oneperType03_1
+        rootTag = 'oneperType01_1'
+        rootClass = oneperType01_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     CapturedNsmap_, namespacedefs = get_required_ns_prefix_defs(rootNode)
@@ -1280,8 +1280,8 @@ def parseEtree(inFileName, silence=False, print_warnings=True,
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType03_1'
-        rootClass = oneperType03_1
+        rootTag = 'oneperType01_1'
+        rootClass = oneperType01_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1323,8 +1323,8 @@ def parseString(inString, silence=False, print_warnings=True):
     gds_collector = GdsCollector_()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType03_1'
-        rootClass = oneperType03_1
+        rootTag = 'oneperType01_1'
+        rootClass = oneperType01_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     if not SaveElementTreeNode:
@@ -1351,8 +1351,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'oneperType03_1'
-        rootClass = oneperType03_1
+        rootTag = 'oneperType01_1'
+        rootClass = oneperType01_1
     rootObj = rootClass.factory()
     rootObj.build(rootNode, gds_collector_=gds_collector)
     # Enable Python to collect the space used by the DOM.
@@ -1360,8 +1360,8 @@ def parseLiteral(inFileName, silence=False, print_warnings=True):
         doc = None
         rootNode = None
 ##     if not silence:
-##         sys.stdout.write('#from oneperType03_1One import *\n\n')
-##         sys.stdout.write('import oneperType03_1One as model_\n\n')
+##         sys.stdout.write('#from oneperType01_1One import *\n\n')
+##         sys.stdout.write('import oneperType01_1One as model_\n\n')
 ##         sys.stdout.write('rootObj = model_.rootClass(\n')
 ##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
@@ -1392,9 +1392,5 @@ RenameMappings_ = {
 }
 __all__ = [
     "oneperType01_1",
-    "oneperType01_2",
-    "oneperType02_1",
-    "oneperType02_2",
-    "oneperType03_1",
-    "oneperType03_2"
+    "oneperType01_2"
 ]
